## Installation

`pip install topsis-twesha-102017195`

## How to use it?

Open terminal and type square and then input the integer

## License

This repository is licensed under the MIT license.
See LICENSE for details.
